@@ -2,7 +2,14 @@ import os
 from typing import *
 
 from cognite.seismic._api.api import API
-from cognite.seismic._api.utility import LineRange, MaybeString, Metadata, get_identifier, get_search_spec
+from cognite.seismic._api.utility import (
+    LineRange,
+    MaybeString,
+    Metadata,
+    get_coverage_spec,
+    get_identifier,
+    get_search_spec,
+)
 from cognite.seismic.data_classes.api_types import BinaryHeader, Geometry, Seismic, TextHeader, VolumeDef
 from google.protobuf.struct_pb2 import Struct
 from google.protobuf.wrappers_pb2 import Int32Value as i32
@@ -11,8 +18,12 @@ from google.protobuf.wrappers_pb2 import StringValue
 if not os.getenv("READ_THE_DOCS"):
     from cognite.seismic.protos.types_pb2 import CRS as CRSProto
     from cognite.seismic.protos.types_pb2 import GeoJson, Wkt
-    from cognite.seismic.protos.v1.seismic_service_datatypes_pb2 import Identifier, OptionalMap
-    from cognite.seismic.protos.v1.seismic_service_datatypes_pb2 import VolumeDef as VolumeDefPB
+    from cognite.seismic.protos.v1.seismic_service_datatypes_pb2 import (
+        Identifier,
+        OptionalMap,
+        CoverageSpec,
+        VolumeDef as VolumeDefPB,
+    )
     from cognite.seismic.protos.v1.seismic_service_messages_pb2 import (
         CreateSeismicRequest,
         DeleteSeismicRequest,
@@ -101,7 +112,9 @@ class SeismicAPI(API):
         include_volume_definition: bool = False,
         include_seismic_store: bool = False,
         include_partition: bool = False,
-        include_coverage: bool = False,
+        include_coverage=False,
+        coverage_crs: Optional[str] = None,
+        coverage_format: Optional[str] = None,
         get_all: bool = False,
     ) -> Iterable[Seismic]:
         """Search for seismics.
@@ -124,13 +137,21 @@ class SeismicAPI(API):
             include_volume_definition (bool): If true, includes the volume def in the responses
             include_seismic_store (bool): If true, include the seismic store info in the responses
             include_partition (bool): If true, include the partition info in the responses
-            include_coverage (bool): If true, include the coverage in the responses
-
+            coverage_crs (str|None): If specified, includes the coverage in the given CRS. Either coverage_crs or coverage_format must be specified to retrieve coverage.
+            coverage_format (str|None): One of "wkt", "geojson". If specified, includes the coverage as the given format.
             get_all (bool): Whether to instead retrieve all visible Seismic. Equivalent to list().
 
         Returns:
             Iterable[Seismic]: The list of matching Seismics
         """
+
+        if include_coverage:
+            raise DeprecationWarning(
+                """include_coverage is deprecated. Use coverage_crs and coverage_format instead.
+For example, search(coverage_format="wkt") is identical to using include_coverage=True. Refer to the SDK documentation for more info.
+"""
+            )
+
         if get_all:
             req = SearchSeismicsRequest()
         else:
@@ -150,19 +171,23 @@ class SeismicAPI(API):
         req.include_volume_definition = include_volume_definition
         req.include_seismic_store = include_seismic_store
         req.include_partition = include_partition
-        req.include_coverage = include_coverage
+        if coverage_crs is not None or coverage_format is not None:
+            req.coverage = get_coverage_spec(coverage_crs, coverage_format)
 
         results = self.query.SearchSeismics(req, metadata=self.metadata)
         return [Seismic.from_proto(s) for s in results]
 
     def list(
         self,
+        *,
         include_text_header: bool = False,
         include_binary_header: bool = False,
         include_line_range: bool = False,
         include_volume_definition: bool = False,
         include_seismic_store: bool = False,
         include_partition: bool = False,
+        coverage_crs: MaybeString = None,
+        coverage_format: MaybeString = None,
     ) -> Iterable[Seismic]:
         return self.search(
             get_all=True,
@@ -172,9 +197,18 @@ class SeismicAPI(API):
             include_volume_definition=include_volume_definition,
             include_seismic_store=include_seismic_store,
             include_partition=include_partition,
+            coverage_crs=coverage_crs,
+            coverage_format=coverage_format,
         )
 
-    def get(self, *, id: Union[int, None] = None, external_id: MaybeString = None) -> Seismic:
+    def get(
+        self,
+        *,
+        id: Union[int, None] = None,
+        external_id: MaybeString = None,
+        coverage_crs: MaybeString = None,
+        coverage_format: MaybeString = None,
+    ) -> Seismic:
         """Get a seismic by id or external id.
 
         Equivalent to search("seismic", id=) or search("seismic", external_id=), returning all info.
@@ -182,6 +216,8 @@ class SeismicAPI(API):
         Args:
             id (int | None): id of seismic to get
             external_id (str | None): external id of seismic to get
+            coverage_crs (str | None): The CRS of the received coverage. Defaults to the file's CRS.
+            coverage_format (str | None): The desired file format for the coverage. Defaults to WKT.
 
         Returns:
             :py:class:`~cognite.seismic.data_classes.api_types.Seismic`: The matching seismic
@@ -201,7 +237,8 @@ class SeismicAPI(API):
                 include_volume_definition=True,
                 include_seismic_store=True,
                 include_partition=True,
-                include_coverage=True,
+                coverage_crs=coverage_crs,
+                coverage_format=coverage_format,
             )
         ]
 
